@@ -52,6 +52,11 @@ struct _GnomeVFSAddress {
 
 #ifdef ENABLE_IPV6
 
+/* OSX seems to already define this */
+# if defined(SIN6_LEN) && defined(__APPLE__)
+#  undef SIN6_LEN
+# endif
+
 # define SIN6_LEN			sizeof (struct sockaddr_in6)
 # define SIN6(__s)				((struct sockaddr_in6 *) __s)
 # define VALID_AF(__sa)			(__sa->sa_family == AF_INET  || __sa->sa_family == AF_INET6)
@@ -288,8 +293,7 @@ gnome_vfs_address_to_string (GnomeVFSAddress *address)
 
 /**
  * gnome_vfs_address_get_ipv4:
- * @address: A #GnomeVFSAddress
- * 
+ * @address: A #GnomeVFSAddress.
  * 
  * Returns: The associated IPv4 address in network byte order.
  *
@@ -552,7 +556,7 @@ gnome_vfs_address_equal (const GnomeVFSAddress *a,
  * gnome_vfs_address_dup:
  * @address: A #GnomeVFSAddress.
  * 
- * Duplicates @adderss.
+ * Duplicates @address.
  * 
  * Return value: Duplicated @address or %NULL if @address was not valid.
  *
