@@ -153,6 +153,7 @@ gnome_vfs_set_file_info_mask_get_type (void)
       { GNOME_VFS_SET_FILE_INFO_TIME, "GNOME_VFS_SET_FILE_INFO_TIME", "time" },
       { GNOME_VFS_SET_FILE_INFO_ACL, "GNOME_VFS_SET_FILE_INFO_ACL", "acl" },
       { GNOME_VFS_SET_FILE_INFO_SELINUX_CONTEXT, "GNOME_VFS_SET_FILE_INFO_SELINUX_CONTEXT", "selinux-context" },
+      { GNOME_VFS_SET_FILE_INFO_SYMLINK_NAME, "GNOME_VFS_SET_FILE_INFO_SYMLINK_NAME", "symlink-name" },
       { 0, NULL, NULL }
     };
     etype = g_flags_register_static ("GnomeVFSSetFileInfoMask", values);
@@ -352,6 +353,8 @@ gnome_vfs_result_get_type (void)
       { GNOME_VFS_ERROR_NAMESERVER, "GNOME_VFS_ERROR_NAMESERVER", "error-nameserver" },
       { GNOME_VFS_ERROR_LOCKED, "GNOME_VFS_ERROR_LOCKED", "error-locked" },
       { GNOME_VFS_ERROR_DEPRECATED_FUNCTION, "GNOME_VFS_ERROR_DEPRECATED_FUNCTION", "error-deprecated-function" },
+      { GNOME_VFS_ERROR_INVALID_FILENAME, "GNOME_VFS_ERROR_INVALID_FILENAME", "error-invalid-filename" },
+      { GNOME_VFS_ERROR_NOT_A_SYMBOLIC_LINK, "GNOME_VFS_ERROR_NOT_A_SYMBOLIC_LINK", "error-not-a-symbolic-link" },
       { GNOME_VFS_NUM_ERRORS, "GNOME_VFS_NUM_ERRORS", "num-errors" },
       { 0, NULL, NULL }
     };
@@ -392,6 +395,20 @@ gnome_vfs_module_callback_full_authentication_out_flags_get_type (void)
   }
   return etype;
 }
+GType
+gnome_vfs_module_callback_authentication_auth_type_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { AuthTypeBasic, "AuthTypeBasic", "basic" },
+      { AuthTypeDigest, "AuthTypeDigest", "digest" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("GnomeVFSModuleCallbackAuthenticationAuthType", values);
+  }
+  return etype;
+}
 
 /* enumerations from "gnome-vfs-utils.h" */
 GType
